@@ -1,11 +1,9 @@
 from __future__ import unicode_literals
 
-from mopidy.mpd.protocol import handle_request
-from mopidy.mpd.exceptions import (
-    MpdPasswordError, MpdPermissionError)
+from mopidy.mpd import exceptions, protocol
 
 
-@handle_request(r'close$', auth_required=False)
+@protocol.commands.add('close', auth_required=False)
 def close(context):
     """
     *musicpd.org, connection section:*
@@ -17,7 +15,7 @@ def close(context):
     context.session.close()
 
 
-@handle_request(r'kill$')
+@protocol.commands.add('kill', list_command=False)
 def kill(context):
     """
     *musicpd.org, connection section:*
@@ -26,10 +24,10 @@ def kill(context):
 
         Kills MPD.
     """
-    raise MpdPermissionError(command='kill')
+    raise exceptions.MpdPermissionError(command='kill')
 
 
-@handle_request(r'password\ "(?P<password>[^"]+)"$', auth_required=False)
+@protocol.commands.add('password', auth_required=False)
 def password(context, password):
     """
     *musicpd.org, connection section:*
@@ -42,10 +40,10 @@ def password(context, password):
     if password == context.password:
         context.dispatcher.authenticated = True
     else:
-        raise MpdPasswordError('incorrect password')
+        raise exceptions.MpdPasswordError('incorrect password')
 
 
-@handle_request(r'ping$', auth_required=False)
+@protocol.commands.add('ping', auth_required=False)
 def ping(context):
     """
     *musicpd.org, connection section:*
